"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ShadowToggle = void 0;
var _react = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _reactNativeSkia = require("@shopify/react-native-skia");
var _reactNativeReanimated = _interopRequireWildcard(require("react-native-reanimated"));
var _constants = require("../constants.js");
var _utils = require("../utils.js");
var _jsxRuntime = require("react/jsx-runtime");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
const PressButton = _reactNativeReanimated.default.createAnimatedComponent(_reactNative.Pressable);

/**
 * ShadowToggle
 * ----------------
 * A toggle component that casts a shadow when active.
 * The shadow effect is created using the `@shopify/react-native-skia` library.
 *
 * @param initialDepth - The initial depth of the shadow
 * @param shadowSpace - The space between the shadow and the component
 * @param isActive - Whether the shadow is active
 * @param activeColor - The color of the shadow when active
 */
const ShadowToggle = exports.ShadowToggle = /*#__PURE__*/(0, _react.memo)(function ShadowToggle({
  width: _width = 0,
  height: _height = 0,
  initialDepth = 3,
  shadowSpace = 6,
  shadowBlur = 10,
  shadowColor = _constants.DEFAULT_SHADOW_COLOR,
  reflectedLightColor = _constants.DEFAULT_REFLECTED_LIGHT_COLOR,
  duration = 200,
  damping = 0.8,
  isReflectedLightEnabled = true,
  isActive = false,
  activeColor,
  backgroundColor,
  style,
  ...props
}) {
  const [boxSize, setBoxSize] = _react.default.useState({
    width: _width,
    height: _height
  });

  // Determine the final background color (pulling from `props.style` or a default).
  const _backgroundColor = (0, _utils.getBackgroundColor)({
    style,
    backgroundColor
  });
  const boxRadius = Number(style ? style.borderRadius : 0) || 10;
  const depth = (0, _reactNativeReanimated.useSharedValue)(initialDepth);
  const offset = (0, _reactNativeReanimated.useDerivedValue)(() => depth.value);
  const rfOffset = (0, _reactNativeReanimated.useDerivedValue)(() => (0, _reactNativeReanimated.interpolate)(depth.value, [-initialDepth, initialDepth * damping], [-3, 3]));
  const animatedBackgroundColor = (0, _reactNativeReanimated.useDerivedValue)(() => (0, _reactNativeReanimated.interpolateColor)(depth.value, [initialDepth, -initialDepth * damping], [_backgroundColor, activeColor || _backgroundColor]));
  const inset = (0, _reactNativeReanimated.useDerivedValue)(() => depth.value <= 0);
  const blur = (0, _reactNativeReanimated.useDerivedValue)(() => (0, _reactNativeReanimated.interpolate)(depth.value, [shadowBlur, 0], [0, initialDepth * damping]));
  (0, _reactNativeReanimated.useAnimatedReaction)(() => isActive, next => {
    depth.value = (0, _reactNativeReanimated.withTiming)(next ? -initialDepth * damping : initialDepth, {
      duration
    });
  }, [isActive]);
  return /*#__PURE__*/(0, _jsxRuntime.jsxs)(PressButton, {
    ...props,
    onLayout: ({
      nativeEvent: {
        layout
      }
    }) => setBoxSize({
      width: layout.width,
      height: layout.height
    }),
    style: [style, _constants.COMMON_STYLES.canvasWrapper],
    children: [boxSize.width === 0 && boxSize.height === 0 ? null : /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNativeSkia.Canvas, {
      style: [style, _constants.COMMON_STYLES.canvas, {
        width: boxSize.width,
        height: boxSize.height
      }],
      children: /*#__PURE__*/(0, _jsxRuntime.jsxs)(_reactNativeSkia.RoundedRect, {
        x: shadowSpace,
        y: shadowSpace,
        width: boxSize.width - shadowSpace * 2,
        height: boxSize.height - shadowSpace * 2,
        r: boxRadius,
        color: animatedBackgroundColor // The background fill of the rect
        ,
        children: [/*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNativeSkia.Shadow, {
          dx: offset,
          dy: offset,
          blur: blur,
          color: shadowColor,
          inner: inset
        }), isReflectedLightEnabled && /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNativeSkia.Shadow, {
          dx: rfOffset,
          dy: rfOffset,
          blur: blur,
          color: reflectedLightColor,
          inner: true
        })]
      })
    }), props.children]
  });
});
//# sourceMappingURL=ShadowToggle.js.map